find_by_args

Function find_by_args 

fn find_by_args(entity: &Entity, entity_args: &EntityArgs) -> bool
Helper function finding by name, note that a lot more helpers could be done to find by other criterias