fn update_defaults(entity_args: &EntityArgs, e: &mut Entity)Expand description
Update the default values of the entity with sensible defaults
fn update_defaults(entity_args: &EntityArgs, e: &mut Entity)Update the default values of the entity with sensible defaults