vec_entities_mut

Function vec_entities_mut 

fn vec_entities_mut<'a>(
    e_type: &'a EntityType,
    epoch_info: &'a mut EpochInfo,
) -> &'a mut Vec<Entity>
Returns a mutable slice over the entities of the requested type from the given EpochInfo.

Like vec_entities, this function selects the appropriate collection based on e_type. Unimplemented variants will panic due to the todo!().

Arguments

  • e_type - The type of entities to retrieve.
  • epoch_info - The epoch information containing the collections.

Returns

A mutable reference to the vector containing the requested entities.
The lifetime of the returned slice is tied to that of epoch_info.