EntityArgs

Struct EntityArgs 

pub struct EntityArgs {
    pub identifier: Option<EntityIdentifier>,
    pub delta: bool,
    pub rng: RngLevel,
    pub pos_exact: Option<Position>,
    pub pos: Option<Position>,
    pub duration: Option<EntityDuration>,
    pub bounds: Option<EffectBounds>,
    pub effect: Option<EffectApplication>,
    pub stats: Vec<StatPair>,
}
Arguments required for any entity operation.

All fields are required. The rng field determines how unspecified stat values are handled when an entity is created or edited.

Fields

identifier: Option<EntityIdentifier>

The identifier either a name or a @tag

delta: bool

Applies a delta to stats instead of setting the values

rng: RngLevel

Non specified stat Repartition

pos_exact: Option<Position>

Adds at a specific position

pos: Option<Position>

Adds at a specific position

duration: Option<EntityDuration>

The duration of the entity

bounds: Option<EffectBounds>

The bounds of the effect of the entity

effect: Option<EffectApplication>

How is the effect of the entity applied

stats: Vec<StatPair>

All stats pairs involved