fn find_by_args(entity: &Entity, entity_args: &EntityArgs) -> boolExpand description
Helper function finding by name, note that a lot more helpers could be done to find by other criterias
fn find_by_args(entity: &Entity, entity_args: &EntityArgs) -> boolHelper function finding by name, note that a lot more helpers could be done to find by other criterias