fn update_stats(entity_args: &EntityArgs, e: &mut Entity)Expand description
Update the given stats with the given argumenbts Note that this function will not change name & id due to the usage variance between caller
fn update_stats(entity_args: &EntityArgs, e: &mut Entity)Update the given stats with the given argumenbts Note that this function will not change name & id due to the usage variance between caller